==> linkv_rtc_im-0.3.6.tar.gz: android/src/main/java/com/linkv/lvrtmsdk/LVRTMEngine.java <==
package com.linkv.lvrtmsdk;

import android.app.Application;
import android.view.ViewGroup;

import com.im.imcore.IMBridger;
import com.im.imlogic.IMMsg;
import com.im.imlogic.LVIMSDK;
import com.im.imlogic.LVPushContent;
import com.linkv.rtcsdk.LinkVRTCEngine;
import com.linkv.rtcsdk.bean.VideoQuality;
import com.linkv.rtcsdk.utils.LogUtils;


/**
 * Created by Xiaohong on 2020/7/18.
 * desc:
 */
public class LVRTMEngine {
    private static String TAG = "LVRTMEngine";

    // 3为自研 4为即构
    public static final int SDK_TYPE_LVRTC = 3;
    public static final int SDK_TYPE_ZEGO = 4;
    private final Application mApplication;

    protected IRoomEventHandler mRoomEventHandler = null;
    private LinkVRTCEngine mRTCEngine;
    private LVIMSDK mIMSDK;
    // 构建消息对象失败错误码
    private final static int ERROR_BUILD_MSG = 1001;


    /**
     * 创建并初始化音视频引擎
     *
     * @param application        应用的Application上下文
     * @param rtcAppID           rtc的appId
     * @param rtcAppKey          rtc的appKey
     * @param imAppID            IM的appId
     * @param imAppKey           IM的appKey
     * @param sdkType            常量SDK_TYPE_LVRTC为LinkV引擎，SDK_TYPE_ZEGO为即构引擎。
     * @param isDebug            是否测试环境
     * @param isInternationalEnv 是否国际环境（仅linkv有效）
     * @param iInitHandler       结果回调
     * @return 音视频引擎
     */
    public static LVRTMEngine createEngine(Application application, String rtcAppID, String rtcAppKey, String imAppID, String imAppKey, int sdkType, boolean isDebug, boolean isInternationalEnv, LinkVRTCEngine.IInitHandler iInitHandler) {
        return new LVRTMEngine(application, rtcAppID, rtcAppKey, imAppID, imAppKey, sdkType, isDebug, isInternationalEnv, iInitHandler);
    }

    // 房间事件监听器设置。
    public void setRoomEventHandler(IRoomEventHandler roomEventHandler) {
        mRoomEventHandler = roomEventHandler;
        mRTCEngine.setEventHandler(eventHandler);
    }

    private LVRTMEngine(Application application, String rtcAppID, String rtcAppKey, String imAppID, String imAppKey, int sdkType, boolean isDebug, boolean isInternationalEnv, LinkVRTCEngine.IInitHandler iInitHandler) {
        mApplication = application;
        mRTCEngine = LinkVRTCEngine.createEngine(application, rtcAppID, rtcAppKey, sdkType, isDebug, isInternationalEnv, iInitHandler);
        mIMSDK = LVIMSDK.sharedInstance();
        // 设置是否debug环境
        mIMSDK.setDebugEnableState(isDebug);
        mIMSDK.initWithAppId(application, imAppID, imAppKey);
        mIMSDK.start();
    }


    // 设置是否打开日志
    public void setLogOpen(boolean isOpen) {
        // 打开RTC的日志
        mRTCEngine.setLogOpen(isOpen);
        // 打开IM的日志
        mIMSDK.setLogVisibleState(isOpen);
    }

    /**
     * 推流参数配置
     *
     * @param videoConfigLevel 推流参数预设值
     */
    public void setVideoConfig(LinkVRTCEngine.VideoConfigLevel videoConfigLevel) {
        mRTCEngine.setVideoConfig(videoConfigLevel);
    }


    // 登录
    public int loginUser(String uid) {
        return mIMSDK.login(uid, "");
    }

    // 设置IM鉴权监听
    public void setIMAuthEventListener(IMBridger.IMModuleEventListener listener) {
        mIMSDK.setEventListener(listener);
    }

    // 设置全局消息监听
    public void setGlobalReceiveMessageListener(IMBridger.IMReceiveMessageListener listener) {
        mIMSDK.setGlobalReceiveMessageListener(listener);
    }


    /**
     * 发送私信消息
     *
     * @param sub      媒体类型
     * @param tid      接收者ID
     * @param type     消息的自定义扩展类型，可作为消息标识，但不能传空或者空串。
     * @param content  消息内容
     * @param pushContent  推送的内容(包括推送通知标题，推送通知内容和推送负载数据,离线消息会以推送通知的形式发送)
     * @param listener 发送结果监听
     */
    public void sendPrivateMessage(MessageSubType sub, String tid, String type, String content,LVPushContent pushContent, IMBridger.IMSendMessageListener listener) {
        sendPrivateMessage(sub, tid, type, content, pushContent, null, null, null, null, listener);
    }

    /**
     * 发送私信消息
     *
     * @param sub          媒体类型
     * @param tid          接收者ID
     * @param type         消息的自定义扩展类型，可作为消息标识，但不能传空或者空串。
     * @param content      消息内容
     * @param pushContent  推送的内容(包括推送通知标题，推送通知内容和推送负载数据,离线消息会以推送通知的形式发送)
     * @param extend3      扩展，暂未使用
     * @param extend4      私信,群组的语音数据
     * @param targetAppID  跨应用发消息时应用appId
     * @param targetAppUID 跨应用发消息的用户ID
     * @param listener     发送结果监听
     */
    public void sendPrivateMessage(MessageSubType sub, String tid, String type, String content, LVPushContent pushContent, String extend3, byte[] extend4, String targetAppID, String targetAppUID, IMBridger.IMSendMessageListener listener) {
        IMMsg msg = IMMsg.buildPrivateMessage(sub.value, tid, type, content, pushContent, extend3, extend4, targetAppID, targetAppUID);
        if (msg != null) {
           int rs =  mIMSDK.sendMessage(msg, null, listener);
           if (rs != 0) {
               //发送消息失败，直接调用发送失败回调
               listener.onIMSendMessageCallback(rs, tid, msg, null);
           }
        } else {
            // 构建消息失败，直接调用发送失败回调
            listener.onIMSendMessageCallback(ERROR_BUILD_MSG, tid, null, null);
        }
    }


    /**
     * 发送房间消息
     *
     * @param targetId   房间Id
     * @param msgContent 消息内容
     * @param listener   发送结果监听
     */
    public void sendRoomMessage(String targetId, String msgContent, IMBridger.IMSendMessageListener listener) {
        sendRoomMessage(targetId, msgContent, "msgTye", listener);
    }

    /**
     * 发送房间消息
     *
     * @param targetId   房间Id
     * @param msgContent 消息内容
     * @param msgType    消息的自定义扩展类型，可作为消息标识，但不能传空或者空串。
     * @param listener   发送结果监听
     */
    public void sendRoomMessage(String targetId, String msgContent, String msgType, IMBridger.IMSendMessageListener listener) {
        IMMsg msg = IMMsg.buildChatRoomMessage(targetId, msgType, msgContent);
        if (msg != null) {
            int rs =  mIMSDK.sendMessage(msg, null, listener);
            if (rs != 0) {
                //发送消息失败，直接调用发送失败回调
                listener.onIMSendMessageCallback(rs, targetId, msg, null);
            }
        } else {
            // 构建消息失败，直接调用发送失败回调
            listener.onIMSendMessageCallback(ERROR_BUILD_MSG, targetId, null, null);
        }
    }

    // 进入房间
    public void loginRoom(String uid, String roomId, boolean isHost, boolean isAudioOnly) {
        // 房间消息监听
        mIMSDK.setChatroomReceiveMessageListener(new IMBridger.IMReceiveMessageListener() {
            @Override
            public boolean onIMReceiveMessageFilter(int cmdtype, int subtype, int diytype, int dataid, String fromid, String toid, String msgType, byte[] msgContent, int waitings, int packetSize, int waitLength, int bufferSize) {
                return false;
            }

            @Override
            public int onIMReceiveMessageHandler(String owner, final IMMsg msg, int waitings, int packetSize, int waitLength, int bufferSize) {
                if (msg != null && mRoomEventHandler != null) {
                    mRoomEventHandler.onRoomMessageReceive(msg);
                }
                return 0;
            }
        });

        mIMSDK.joinChatRoom(roomId, null, new IMBridger.IMSendMessageListener() {
            @Override
            public void onIMSendMessageCallback(int ecode, String tid, IMMsg imMsg, Object o) {
                if (ecode == 0) { // 加入IM房间成功
                    // 加入RTC房间
                    LogUtils.d(TAG, "IM joinChatRoom succ tid = " + tid);
                    mRTCEngine.loginRoom(uid, roomId, isHost, isAudioOnly);
                } else {
                    // 直接回调加入房间失败方法
                    if (mRoomEventHandler != null) {
                        mRoomEventHandler.onRoomDisconnect(ecode, roomId);
                    }
                }
            }
        });
    }

    // 退出房间
    public void logoutRoom() {
        mRTCEngine.logoutRoom();
        mIMSDK.leaveChatRoom(getRoomId(), null, null);
        mIMSDK.setChatroomReceiveMessageListener(null);
    }

    // 开始预览
    public void startPreview(String userId, ViewGroup container, boolean isZOrderMediaOverlay) {
        mRTCEngine.startPreview(userId, container, isZOrderMediaOverlay);
    }

    // 开始推流
    public void startPublishing() {
        mRTCEngine.startPublishing();
    }

    // 开始拉流
    public void startPlayingStream(String userId, ViewGroup container, boolean isZOrderMediaOverlay) {
        mRTCEngine.startPlayingStream(userId, container, isZOrderMediaOverlay);
    }


    /**
     * 停止预览
     */
    public void stopPreview() {
        mRTCEngine.stopPreview();
    }


    /**
     * 推流质量更新间隔
     *
     * @param second 间隔秒数
     */
    public void setPublishQualityMonitorCycle(int second) {
        mRTCEngine.setPublishQualityMonitorCycle(second);
    }

    /**
     * 设置拉流质量更新间隔
     *
     * @param second 间隔秒数
     */
    public void setPlayQualityMonitorCycle(int second) {
        mRTCEngine.setPlayQualityMonitorCycle(second);
    }


    /**
     * 停止推流
     */
    public void stopPublishingStream() {
        mRTCEngine.stopPublishingStream();
    }

    /**
     * 停止拉流
     *
     * @param userId 用户流ID
     */
    public void stopPlayingStream(String userId) {
        mRTCEngine.stopPlayingStream(userId);
    }


    // 转换前后置摄像头
    public void useFrontCamera(boolean mFrontCamera) {
        mRTCEngine.useFrontCamera(mFrontCamera);
    }

    // 获取支持连麦数
    public int getSupportLine() {
        return mRTCEngine.getSupportLine();
    }

    // 获取SDK类型 1为声网，3为自研，4为zego。
    public int getSDKType() {
        return mRTCEngine.getSDKType();
    }

    // 静音推流
    public void setMuteOutput(boolean mute) {
        mRTCEngine.setMuteOutput(mute);
    }

    /**
     * 打开摄像头数据
     */
    public void startCapture(){
        mRTCEngine.startCapture();
    }

    /**
     * 关闭摄像头数据
     */
    public void stopCapture(){
        mRTCEngine.stopPreview();
    }

    // 获取房间ID
    public String getRoomId() {
        return mRTCEngine.getRoomId();
    }

    // 释放引擎
    public void unInitSDK() {
        mRTCEngine.unInitSDK();
        mIMSDK.release();
    }

    // 是否已登录IM SDK
    public boolean isIMLoginSucceed() {
        return mIMSDK.isAppUserLoginSucceed();
    }

    // IM是否鉴权成功
    public boolean isIMAuthed() {
        return mIMSDK.isAuthed();
    }

    /**
     * 设置滤镜美颜级别
     *
     * @param beautyLevel 滤镜美颜级别
     */
    public void setBeautyLevel(float beautyLevel) {
        if (mRTCEngine != null) {
            mRTCEngine.setBeautyLevel(beautyLevel);
        }
    }

    /**
     * 设置滤镜明亮度
     *
     * @param brightLevel 滤镜明亮度
     */
    public void setBrightLevel(float brightLevel) {
        if (mRTCEngine != null) {
            mRTCEngine.setBrightLevel(brightLevel);
        }
    }

    /**
     * 设置滤镜饱和度
     *
     * @param toneLevel 滤镜饱和度级别
     */
    public void setToneLevel(float toneLevel) {
        if (mRTCEngine != null) {
            mRTCEngine.setToneLevel(toneLevel);
        }
    }


    // RTC SDK的version
    public String getSdkVersion() {
        return mRTCEngine.getVersionName();
    }


    /**
     * RTM SDK对外回调接口
     */
    public interface IRoomEventHandler {

        int INIT_RESULT_SUCCEED = LinkVRTCEngine.IInitHandler.INIT_RESULT_SUCCEED;
        int INIT_RESULT_FAIL = LinkVRTCEngine.IInitHandler.INIT_RESULT_FAIL;

        // 远端流停止
        void onRemoteStreamEnd(String userId);

        // 远端流加入
        void onRemoteStreamAdd(String userId);

        /**
         * 房间连接失败
         *
         * @param errorCode 错误码，文档中要分开写zego和自研的错误码。
         * @param roomID
         */
        void onRoomDisconnect(int errorCode, String roomID);

        // 房间连接成功
        void onRoomConnected(String roomID);

        // 远端流质量更新
        void onRemoteQualityUpdate(String streamID, VideoQuality quality);

        // 推流质量更新
        void onPublisherQualityUpdate(String streamID, VideoQuality quality);

        // 远端流视频宽高更新
        void onVideoSizeChanged(String streamID, int width, int height);

        // 收到房间消息
        void onRoomMessageReceive(IMMsg msg);

        // 推流状态更新
        void onPublishStateUpdate(int state);

        // 拉流状态更新
        void onPlayStateUpdate(int state, String userId);

    }

    private LinkVRTCEngine.IEventHandler eventHandler = new LinkVRTCEngine.IEventHandler() {
        @Override
        public void onRemoteStreamEnd(String userId) {
            if (mRoomEventHandler != null) {
                mRoomEventHandler.onRemoteStreamEnd(userId);
            }
        }

        @Override
        public void onRemoteStreamAdd(String userId) {
            if (mRoomEventHandler != null) {
                mRoomEventHandler.onRemoteStreamAdd(userId);
            }
        }

        @Override
        public void onRoomDisconnect(int i, String roomId) {
            if (mRoomEventHandler != null) {
                mRoomEventHandler.onRoomDisconnect(i, roomId);
            }
        }

        @Override
        public void onRoomConnected(String roomId) {
            if (mRoomEventHandler != null) {
                mRoomEventHandler.onRoomConnected(roomId);
            }
        }

        @Override
        public void onRemoteQualityUpdate(String s, VideoQuality videoQuality) {
            if (mRoomEventHandler != null) {
                mRoomEventHandler.onRemoteQualityUpdate(s, videoQuality);
            }
        }

        @Override
        public void onPublisherQualityUpdate(String s, VideoQuality videoQuality) {
            if (mRoomEventHandler != null) {
                mRoomEventHandler.onPublisherQualityUpdate(s, videoQuality);
            }
        }

        @Override
        public void onVideoSizeChanged(String s, int i, int i1) {
            if (mRoomEventHandler != null) {
                mRoomEventHandler.onVideoSizeChanged(s, i, i1);
            }
        }

        @Override
        public void onPublishStateUpdate(int i) {
            if (mRoomEventHandler != null) {
                mRoomEventHandler.onPublishStateUpdate(i);
            }
        }

        @Override
        public void onPlayStateUpdate(int i, String s) {
            if (mRoomEventHandler != null) {
                mRoomEventHandler.onPlayStateUpdate(i, s);
            }

        }
    };


    public enum MessageSubType {
        //文本类协议
        IM_SUBTYPE_TEXT(0),
        //图片类协议
        IM_SUBTYPE_IMAGE(1),
        //音频类协议
        IM_SUBTYPE_AUDIO(2),
        //视频类协议
        IM_SUBTYPE_VIDEO(3);

        int value;

        MessageSubType(int value) {
            this.value = value;
        }

    }

}

==> linkv_rtc_im-0.3.9.tar.gz: android/src/main/java/com/linkv/lvrtmsdk/LVRTMEngine.java <==
package com.linkv.lvrtmsdk;

import android.app.Application;
import android.util.Log;
import android.view.ViewGroup;
import android.widget.Toast;
import com.im.imcore.IMBridger;
import com.im.imlogic.IMMsg;
import com.im.imlogic.LVIMSDK;
import com.im.imlogic.LVPushContent;
import com.linkv.rtcsdk.LinkVRTCEngine;
import com.linkv.rtcsdk.bean.VideoQuality;
import com.linkv.rtcsdk.utils.LogUtils;
import com.linkv.rtm_flutter_plugin.R;


/**
 * Created by Xiaohong on 2020/7/18.
 * desc:
 */
public class LVRTMEngine {
    private static String TAG = "LVRTMEngine";

    // 3为自研 4为即构
    public static final int SDK_TYPE_LVRTC = 3;
    public static final int SDK_TYPE_ZEGO = 4;
    private final Application mApplication;

    protected IRoomEventHandler mRoomEventHandler = null;
    private LinkVRTCEngine mRTCEngine;
    private LVIMSDK mIMSDK;
    // 构建消息对象失败错误码
    private final static int ERROR_BUILD_MSG = 1001;


    /**
     * 创建并初始化音视频引擎
     *
     * @param application        应用的Application上下文
     * @param rtcAppID           rtc的appId
     * @param rtcAppKey          rtc的appKey
     * @param imAppID            IM的appId
     * @param imAppKey           IM的appKey
     * @param sdkType            常量SDK_TYPE_LVRTC为LinkV引擎，SDK_TYPE_ZEGO为即构引擎。
     * @param isDebug            是否测试环境
     * @param isInternationalEnv 是否国际环境（仅linkv有效）
     * @param iInitHandler       结果回调
     * @return 音视频引擎
     */
    public static LVRTMEngine createEngine(Application application, String rtcAppID, String rtcAppKey, String imAppID, String imAppKey, int sdkType, boolean isDebug, boolean isInternationalEnv, LinkVRTCEngine.IInitHandler iInitHandler) {
        return new LVRTMEngine(application, rtcAppID, rtcAppKey, imAppID, imAppKey, sdkType, isDebug, isInternationalEnv, iInitHandler);
    }

    // 房间事件监听器设置。
    public void setRoomEventHandler(IRoomEventHandler roomEventHandler) {
        mRoomEventHandler = roomEventHandler;
        mRTCEngine.setEventHandler(eventHandler);
    }

    private LVRTMEngine(Application application, String rtcAppID, String rtcAppKey, String imAppID, String imAppKey, int sdkType, boolean isDebug, boolean isInternationalEnv, LinkVRTCEngine.IInitHandler iInitHandler) {
        mApplication = application;
        mRTCEngine = LinkVRTCEngine.createEngine(application, rtcAppID, rtcAppKey, sdkType, isDebug, isInternationalEnv, iInitHandler);
        mIMSDK = LVIMSDK.sharedInstance();
        // 设置是否debug环境
        mIMSDK.setDebugEnableState(isDebug);
        mIMSDK.initWithAppId(application, imAppID, imAppKey);
        mIMSDK.start();
    }


    // 设置是否打开日志
    public void setLogOpen(boolean isOpen) {
        // 打开RTC的日志
        mRTCEngine.setLogOpen(isOpen);
        // 打开IM的日志
        mIMSDK.setLogVisibleState(isOpen);
    }

    /**
     * 推流参数配置
     *
     * @param videoConfigLevel 推流参数预设值
     */
    public void setVideoConfig(LinkVRTCEngine.VideoConfigLevel videoConfigLevel) {
        mRTCEngine.setVideoConfig(videoConfigLevel);
    }


    // 登录
    public int loginUser(String uid, int loginType) {
        return mIMSDK.login(uid, loginType);
    }

    // 设置IM鉴权监听
    public void setIMAuthEventListener(IMBridger.IMModuleEventListener listener) {
        mIMSDK.setEventListener(listener);
    }

    // 设置全局消息监听
    public void setGlobalReceiveMessageListener(IMBridger.IMReceiveMessageListener listener) {
        mIMSDK.setGlobalReceiveMessageListener(listener);
    }


    /**
     * 发送私信消息
     *
     * @param sub      媒体类型
     * @param tid      接收者ID
     * @param type     消息的自定义扩展类型，可作为消息标识，但不能传空或者空串。
     * @param content  消息内容
     * @param pushContent  推送的内容(包括推送通知标题，推送通知内容和推送负载数据,离线消息会以推送通知的形式发送)
     * @param listener 发送结果监听
     */
    public void sendPrivateMessage(MessageSubType sub, String tid, String type, String content,LVPushContent pushContent, IMBridger.IMSendMessageListener listener) {
        sendPrivateMessage(sub, tid, type, content, pushContent, null, null, null, null, listener);
    }

    /**
     * 发送私信消息
     *
     * @param sub          媒体类型
     * @param tid          接收者ID
     * @param type         消息的自定义扩展类型，可作为消息标识，但不能传空或者空串。
     * @param content      消息内容
     * @param pushContent  推送的内容(包括推送通知标题，推送通知内容和推送负载数据,离线消息会以推送通知的形式发送)
     * @param extend3      扩展，暂未使用
     * @param extend4      私信,群组的语音数据
     * @param targetAppID  跨应用发消息时应用appId
     * @param targetAppUID 跨应用发消息的用户ID
     * @param listener     发送结果监听
     */
    public void sendPrivateMessage(MessageSubType sub, String tid, String type, String content, LVPushContent pushContent, String extend3, byte[] extend4, String targetAppID, String targetAppUID, IMBridger.IMSendMessageListener listener) {
        IMMsg msg = IMMsg.buildPrivateMessage(sub.value, tid, type, content, pushContent, extend3, extend4, targetAppID, targetAppUID);
        if (msg != null) {
           int rs =  mIMSDK.sendMessage(msg, null, listener);
           if (rs != 0) {
               //发送消息失败，直接调用发送失败回调
               listener.onIMSendMessageCallback(rs, rs, tid, msg, null);
           }
        } else {
            // 构建消息失败，直接调用发送失败回调
            listener.onIMSendMessageCallback(ERROR_BUILD_MSG, ERROR_BUILD_MSG, tid, null, null);
        }
    }


    /**
     * 发送房间消息
     *
     * @param targetId   房间Id
     * @param msgContent 消息内容
     * @param listener   发送结果监听
     */
    public void sendRoomMessage(String targetId, String msgContent, IMBridger.IMSendMessageListener listener) {
        sendRoomMessage(targetId, msgContent, "msgTye", listener);
    }

    /**
     * 发送房间消息
     *
     * @param targetId   房间Id
     * @param msgContent 消息内容
     * @param msgType    消息的自定义扩展类型，可作为消息标识，但不能传空或者空串。
     * @param listener   发送结果监听
     */
    public void sendRoomMessage(String targetId, String msgContent, String msgType, IMBridger.IMSendMessageListener listener) {
        IMMsg msg = IMMsg.buildChatRoomMessage(targetId, msgType, msgContent);
        if (msg != null) {
            int rs =  mIMSDK.sendMessage(msg, null, listener);
            if (rs != 0) {
                //发送消息失败，直接调用发送失败回调
                listener.onIMSendMessageCallback(rs, rs, targetId, msg, null);
            }
        } else {
            // 构建消息失败，直接调用发送失败回调
            listener.onIMSendMessageCallback(ERROR_BUILD_MSG, ERROR_BUILD_MSG, targetId, null, null);
        }
    }

    // 进入房间
    public void loginRoom(String uid, String roomId, boolean isHost, boolean isAudioOnly) {
        // 房间消息监听
        mIMSDK.setChatroomReceiveMessageListener(new IMBridger.IMReceiveMessageListener() {
            @Override
            public boolean onIMReceiveMessageFilter(int cmdtype, int subtype, int diytype, int dataid, String fromid, String toid, String msgType, byte[] msgContent, int waitings, int packetSize, int waitLength, int bufferSize) {
                return false;
            }

            @Override
            public int onIMReceiveMessageHandler(String owner, final IMMsg msg, int waitings, int packetSize, int waitLength, int bufferSize) {
                if (msg != null && mRoomEventHandler != null) {
                    mRoomEventHandler.onRoomMessageReceive(msg);
                }
                return 0;
            }

            @Override
            public void onIMMessageReadedAcks(long[] longs) {
                
            }
        });

        mIMSDK.chatroomManager.joinChatRoom(roomId, null, new IMBridger.IMSendMessageListener() {
            @Override
            public void onIMSendMessageCallback(int ecode, int rcode, String tid, IMMsg imMsg, Object o) {
                if (ecode == 0) { // 加入IM房间成功
                    // 加入RTC房间
                    LogUtils.d(TAG, "IM joinChatRoom succ tid = " + tid);
                    mRTCEngine.loginRoom(uid, roomId, isHost, isAudioOnly);
                } else {
                    // 直接回调加入房间失败方法
                    if (mRoomEventHandler != null) {
                        mRoomEventHandler.onRoomDisconnect(ecode, roomId);
                    }
                }
            }
        });
    }

    // 退出房间
    public void logoutRoom() {
        mRTCEngine.logoutRoom();
        mIMSDK.chatroomManager.leaveChatRoom(getRoomId(), null, null);
        mIMSDK.setChatroomReceiveMessageListener(null);
    }

    // 开始预览
    public void startPreview(String userId, ViewGroup container, boolean isZOrderMediaOverlay) {
        mRTCEngine.startPreview(userId, container, isZOrderMediaOverlay);
    }

    // 开始推流
    public void startPublishing() {
        mRTCEngine.startPublishing();
    }

    // 开始拉流
    public void startPlayingStream(String userId, ViewGroup container, boolean isZOrderMediaOverlay) {
        mRTCEngine.startPlayingStream(userId, container, isZOrderMediaOverlay);
    }


    /**
     * 停止预览
     */
    public void stopPreview() {
        mRTCEngine.stopPreview();
    }


    /**
     * 推流质量更新间隔
     *
     * @param second 间隔秒数
     */
    public void setPublishQualityMonitorCycle(int second) {
        mRTCEngine.setPublishQualityMonitorCycle(second);
    }

    /**
     * 设置拉流质量更新间隔
     *
     * @param second 间隔秒数
     */
    public void setPlayQualityMonitorCycle(int second) {
        mRTCEngine.setPlayQualityMonitorCycle(second);
    }


    /**
     * 停止推流
     */
    public void stopPublishingStream() {
        mRTCEngine.stopPublishingStream();
    }

    /**
     * 停止拉流
     *
     * @param userId 用户流ID
     */
    public void stopPlayingStream(String userId) {
        mRTCEngine.stopPlayingStream(userId);
    }


    // 转换前后置摄像头
    public void useFrontCamera(boolean mFrontCamera) {
        mRTCEngine.useFrontCamera(mFrontCamera);
    }

    // 获取支持连麦数
    public int getSupportLine() {
        return mRTCEngine.getSupportLine();
    }

    // 获取SDK类型 1为声网，3为自研，4为zego。
    public int getSDKType() {
        return mRTCEngine.getSDKType();
    }

    // 静音推流
    public void setMuteOutput(boolean mute) {
        mRTCEngine.setMuteOutput(mute);
    }

    /**
     * 打开摄像头数据
     */
    public void startCapture(){
        mRTCEngine.startCapture();
    }

    /**
     * 关闭摄像头数据
     */
    public void stopCapture(){
        mRTCEngine.stopPreview();
    }

    // 获取房间ID
    public String getRoomId() {
        return mRTCEngine.getRoomId();
    }

    // 释放引擎
    public void unInitSDK() {
        mRTCEngine.unInitSDK();
        mIMSDK.release();
    }

    // 是否已登录IM SDK
    public boolean isIMLoginSucceed() {
        return mIMSDK.isAppUserLoginSucceed();
    }

    // IM是否鉴权成功
    public boolean isIMAuthed() {
        return mIMSDK.isAuthed();
    }

    /**
     * 设置滤镜美颜级别
     *
     * @param beautyLevel 滤镜美颜级别
     */
    public void setBeautyLevel(float beautyLevel) {
        if (mRTCEngine != null) {
            mRTCEngine.setBeautyLevel(beautyLevel);
        }
    }

    /**
     * 设置滤镜明亮度
     *
     * @param brightLevel 滤镜明亮度
     */
    public void setBrightLevel(float brightLevel) {
        if (mRTCEngine != null) {
            mRTCEngine.setBrightLevel(brightLevel);
        }
    }

    /**
     * 设置滤镜饱和度
     *
     * @param toneLevel 滤镜饱和度级别
     */
    public void setToneLevel(float toneLevel) {
        if (mRTCEngine != null) {
            mRTCEngine.setToneLevel(toneLevel);
        }
    }


    // RTC SDK的version
    public String getSdkVersion() {
        return mRTCEngine.getVersionName();
    }


    /**
     * RTM SDK对外回调接口
     */
    public interface IRoomEventHandler {

        int INIT_RESULT_SUCCEED = LinkVRTCEngine.IInitHandler.INIT_RESULT_SUCCEED;
        int INIT_RESULT_FAIL = LinkVRTCEngine.IInitHandler.INIT_RESULT_FAIL;

        // 远端流停止
        void onRemoteStreamEnd(String userId);

        // 远端流加入
        void onRemoteStreamAdd(String userId);

        /**
         * 房间连接失败
         *
         * @param errorCode 错误码，文档中要分开写zego和自研的错误码。
         * @param roomID
         */
        void onRoomDisconnect(int errorCode, String roomID);

        // 房间连接成功
        void onRoomConnected(String roomID);

        // 远端流质量更新
        void onRemoteQualityUpdate(String streamID, VideoQuality quality);

        // 推流质量更新
        void onPublisherQualityUpdate(String streamID, VideoQuality quality);

        // 远端流视频宽高更新
        void onVideoSizeChanged(String streamID, int width, int height);

        // 收到房间消息
        void onRoomMessageReceive(IMMsg msg);

        // 推流状态更新
        void onPublishStateUpdate(int state);

        // 拉流状态更新
        void onPlayStateUpdate(int state, String userId);

    }

    private LinkVRTCEngine.IEventHandler eventHandler = new LinkVRTCEngine.IEventHandler() {
        @Override
        public void onRemoteStreamEnd(String userId) {
            if (mRoomEventHandler != null) {
                mRoomEventHandler.onRemoteStreamEnd(userId);
            }
        }

        @Override
        public void onRemoteStreamAdd(String userId) {
            if (mRoomEventHandler != null) {
                mRoomEventHandler.onRemoteStreamAdd(userId);
            }
        }

        @Override
        public void onRoomDisconnect(int i, String roomId) {
            if (mRoomEventHandler != null) {
                mRoomEventHandler.onRoomDisconnect(i, roomId);
            }
        }

        @Override
        public void onRoomConnected(String roomId) {
            if (mRoomEventHandler != null) {
                mRoomEventHandler.onRoomConnected(roomId);
            }
        }

        @Override
        public void onRemoteQualityUpdate(String s, VideoQuality videoQuality) {
            if (mRoomEventHandler != null) {
                mRoomEventHandler.onRemoteQualityUpdate(s, videoQuality);
            }
        }

        @Override
        public void onPublisherQualityUpdate(String s, VideoQuality videoQuality) {
            if (mRoomEventHandler != null) {
                mRoomEventHandler.onPublisherQualityUpdate(s, videoQuality);
            }
        }

        @Override
        public void onVideoSizeChanged(String s, int i, int i1) {
            if (mRoomEventHandler != null) {
                mRoomEventHandler.onVideoSizeChanged(s, i, i1);
            }
        }

        @Override
        public void onPublishStateUpdate(int i) {
            if (mRoomEventHandler != null) {
                mRoomEventHandler.onPublishStateUpdate(i);
            }
        }

        @Override
        public void onPlayStateUpdate(int i, String s) {
            if (mRoomEventHandler != null) {
                mRoomEventHandler.onPlayStateUpdate(i, s);
            }

        }
    };


    public enum MessageSubType {
        //文本类协议
        IM_SUBTYPE_TEXT(0),
        //图片类协议
        IM_SUBTYPE_IMAGE(1),
        //音频类协议
        IM_SUBTYPE_AUDIO(2),
        //视频类协议
        IM_SUBTYPE_VIDEO(3);

        int value;

        MessageSubType(int value) {
            this.value = value;
        }

    }

}
